#[repr(C)]pub struct TSInputEdit {
pub start_byte: u32,
pub old_end_byte: u32,
pub new_end_byte: u32,
pub start_point: TSPoint,
pub old_end_point: TSPoint,
pub new_end_point: TSPoint,
}Expand description
A summary of a change to a text document.
The start_byte and start_point values must be less than or equal to the
old_end_byte and old_end_point values, respectively. Passing an edit
that violates these invariants may produce nonsensical results.
Fields
start_byte: u32old_end_byte: u32new_end_byte: u32start_point: TSPointold_end_point: TSPointnew_end_point: TSPointTrait Implementations
Sourceimpl Clone for TSInputEdit
impl Clone for TSInputEdit
Sourcefn clone(&self) -> TSInputEdit
fn clone(&self) -> TSInputEdit
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TSInputEdit
impl Debug for TSInputEdit
Sourceimpl From<&InputEdit> for TSInputEdit
impl From<&InputEdit> for TSInputEdit
Sourcefn from(val: &InputEdit) -> TSInputEdit
fn from(val: &InputEdit) -> TSInputEdit
Converts to this type from the input type.
impl Copy for TSInputEdit