pub struct ParseOptions<'a> {
pub progress_callback: Option<&'a mut dyn FnMut(&ParseState) -> ControlFlow<()>>,
}Fields
progress_callback: Option<&'a mut dyn FnMut(&ParseState) -> ControlFlow<()>>Implementations
Sourceimpl<'a> ParseOptions<'a>
impl<'a> ParseOptions<'a>
pub fn new() -> ParseOptions<'a>
pub fn progress_callback<F>(self, callback: &'a mut F) -> ParseOptions<'a>
Sourcepub fn reborrow(&mut self) -> ParseOptions<'_>
pub fn reborrow(&mut self) -> ParseOptions<'_>
Create a new ParseOptions with a shorter lifetime, borrowing from this one.
This is useful when you need to reuse parse options multiple times, e.g., calling
Parser::parse_with_options multiple times with the same options.