pub struct ParseState(/* private fields */);Expand description
A stateful object that is passed into a [ParseProgressCallback]
to pass in the current state of the parser.
Implementations
Sourceimpl ParseState
impl ParseState
Sourcepub const unsafe fn from_raw(ptr: *mut TSParseState) -> ParseState
pub const unsafe fn from_raw(ptr: *mut TSParseState) -> ParseState
Sourcepub fn into_raw(self) -> *mut TSParseState
pub fn into_raw(self) -> *mut TSParseState
Consumes the ParseState, returning a raw pointer to the underlying C structure.
Sourceimpl ParseState
impl ParseState